#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# List of defaul languages, omitting country code should be okay
DEFAULT_LANGS = (
    "af_za",
    "am_et",
    "ar_aa",
    "as_in",
    "az_az",
    "be_by",
    "bg_bg",
    "bn_bd",
    "bo_bt",
    "br_fr",
    "bs_ba",
    "ca_es",
    "cs_cz",
    "cy_gb",
    "da_dk",
    "de_de",
    "ee_ee",
    "el_gr",
    "en_us",
    "eo_xx",
    "es_es",
    "et_ee",
    "eu_es",
    "fa_ir",
    "fi_fi",
    "fo_fo",
    "fr_fr",
    "ga_ie",
    "gd_gb",
    "gl_es",
    "gu_in",
    "gv_gb",
    "he_il",
    "hi_in",
    "hr_hr",
    "hu_hu",
    "hy_am",
    "id_id",
    "is_is",
    "it_it",
    "iu_ca",
    "ja_jp",
    "ka_ge",
    "kk_kz",
    "kl_gl",
    "km_kh",
    "kn_in",
    "ko_kr",
    "ks_in",
    "kw_gb",
    "ky_kg",
    "lb_lu",
    "lo_la",
    "lt_lt",
    "lv_lv",
    "mi_nz",
    "mk_mk",
    "ml_in",
    "mn_mn",
    "mr_in",
    "ms_my",
    "mt_mt",
    "my_mm",
    "ne_np",
    "nl_nl",
    "nn_no",
    "no_no",
    "nr_za",
    "ny_no",
    "oc_fr",
    "or_in",
    "pa_in",
    "pd_us",
    "ph_ph",
    "pl_pl",
    "pp_an",
    "pt_pt",
    "ro_ro",
    "ru_ru",
    "rw_rw",
    "sa_in",
    "sd_in",
    "si_lk",
    "sk_sk",
    "sl_si",
    "sq_al",
    "sr_rs",
    "ss_za",
    "st_za",
    "sv_se",
    "ta_in",
    "te_in",
    "tg_tj",
    "th_th",
    "tk_tm",
    "tl_ph",
    "tn_za",
    "tr_tr",
    "ts_za",
    "tt_ru",
    "uk_ua",
    "ur_pk",
    "uz_uz",
    "ve_za",
    "vi_vn",
    "wa_be",
    "xh_za",
    "yi_us",
    "zu_za",
    "ast_es",
    "gug_py",
)
